Returns an array that is the string split at tabs, i.e. split(/\t/).
"foo\tgoo\thoo".split_tab => ["foo", "goo", "hoo"]
Returns:
an array that is the string split at tabs, i.e. split(/\t/)
33 34 35
# File 'lib/sixarm_ruby_ramp/string.rb', line 33 def split_tab split(/\t/) end